Name:             pykka
Version:          1.2.1
Release:          13%{?dist}
Summary:          Python library that provides concurrency using actor model
Group:            Development/Libraries
License:          ASL 2.0
URL:              http://www.pykka.org/
Source0:          https://github.com/jodal/pykka/tarball/v%{version}/pykka-%{version}.tar.gz
BuildRequires:    python3-devel
BuildRequires:    python3-sphinx
BuildArch:        noarch

%description
The goal of Pykka is to provide easy to use concurrency abstractions for Python
by using the actor model.

Pykka provides an actor API with two different implementations:

 * ThreadingActor is built on the Python Standard Library’s threading and Queue
   modules, and has no dependencies outside Python itself. It plays well
   together with non-actor threads.
 * GeventActor is built on the gevent library. gevent is a coroutine-based
   Python networking library that uses greenlet to provide a high-level
   synchronous API on top of libevent event loop. It is generally faster, but
   doesn't like playing with other threads.

Much of the naming in Pykka is inspired by the Akka project which implements
actors on the JVM. Though, Pykka does not aim to be a Python port of Akka.

%package -n python3-pykka
Summary:        Python library that provides concurrency using actor model
%{?python_provide:%python_provide python3-pykka}

%description -n python3-pykka
The goal of Pykka is to provide easy to use concurrency abstractions for Python
by using the actor model.

Pykka for Python 3 provides an actor API with one implementation:

 * ThreadingActor is built on the Python Standard Library’s threading and Queue
   modules, and has no dependencies outside Python itself. It plays well
   together with non-actor threads.

Much of the naming in Pykka is inspired by the Akka project which implements
actors on the JVM. Though, Pykka does not aim to be a Python port of Akka.

This package provides Pykka's Python 3 libraries

%package docs
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch
Requires:       devhelp

%description docs
This package provides the documentation for %{name}, e.g. the API as
devhelp docs, and examples.


%prep
%setup -q -c
DIR=`ls -d jodal-pykka-*`
mv $DIR/* ./
mv $DIR/.[a-zA-Z0-9]* ./
rmdir $DIR

%build
%py3_build
cd docs
SPHINXBUILD=sphinx-build-3 make devhelp

%install
%py3_install
mkdir -p $RPM_BUILD_ROOT%{_datarootdir}/devhelp/Pykka
cp -rp docs/_build/devhelp $RPM_BUILD_ROOT%{_datarootdir}/devhelp/Pykka

%files -n python3-pykka
%doc LICENSE README.rst
%{python3_sitelib}/Pykka*
%{python3_sitelib}/pykka

%files docs
%doc examples/
%{_datarootdir}/devhelp/Pykka


%changelog
* Sun Oct 07 2018 My Karlsson <mk@acc.umu.se> - 1.2.1-13
- Remove python2 subpackage (rhbz#1627414)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.2.1-11
- Rebuilt for Python 3.7

* Wed Feb 21 2018 Iryna Shcherbina <ishcherb@redhat.com> - 1.2.1-10
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.2.1-6
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-5
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Tue Aug 18 2015 Jonathan Dieter <jdieter@lesbg.com> - 1.2.1-2
- Update to 1.2.1
- Build Python 3 library (with limited functionality)

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr 16 2013 Jonathan Dieter <jdieter@lesbg.com> - 1.1.0-1
- Update to latest release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.15-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 10 2013 Matěj Cepl <mcepl@redhat.com> - 0.15-3
- Add documentation and examples.

* Mon Aug 27 2012 Jonathan Dieter <jdieter@lesbg.com> - 0.15-2
- Update to latest version
- Remove unneeded sections
- Remove trailing .0 as it's not part of the original versioning
- Remove buildroot tag

* Wed Jan  4 2012 Jonathan Dieter <jdieter@lesbg.com> - 0.13.0-1
- Initial release
